==> qtjambi-qt3drender-5.15.8-sources.jar: io/qt/qt3d/render/QRenderPass.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates a Render Pass</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html">Qt3DRender::QRenderPass</a></p>
 */
public class QRenderPass extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderPass.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#shaderProgram-prop">Qt3DRender::QRenderPass::shaderProgramChanged(Qt3DRender::QShaderProgram*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="shaderProgram")
    public final Signal1<io.qt.qt3d.render.QShaderProgram> shaderProgramChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRenderPass(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderPass() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#QRenderPass">Qt3DRender::QRenderPass::QRenderPass(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderPass(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderPass instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#addFilterKey">Qt3DRender::QRenderPass::addFilterKey(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addFilterKey(io.qt.qt3d.render.QFilterKey filterKey){
        addFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void addFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#addParameter">Qt3DRender::QRenderPass::addParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addParameter(io.qt.qt3d.render.QParameter p){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#addRenderState">Qt3DRender::QRenderPass::addRenderState(Qt3DRender::QRenderState*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addRenderState(io.qt.qt3d.render.QRenderState state){
        addRenderState_native_Qt3DRender_QRenderState_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(state));
    }
    
    @io.qt.QtUninvokable
    private native void addRenderState_native_Qt3DRender_QRenderState_ptr(long __this__nativeId, long state);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#filterKeys">Qt3DRender::QRenderPass::filterKeys()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QFilterKey> filterKeys(){
        return filterKeys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QFilterKey> filterKeys_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#parameters">Qt3DRender::QRenderPass::parameters()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#removeFilterKey">Qt3DRender::QRenderPass::removeFilterKey(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeFilterKey(io.qt.qt3d.render.QFilterKey filterKey){
        removeFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void removeFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#removeParameter">Qt3DRender::QRenderPass::removeParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.QParameter p){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#removeRenderState">Qt3DRender::QRenderPass::removeRenderState(Qt3DRender::QRenderState*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeRenderState(io.qt.qt3d.render.QRenderState state){
        removeRenderState_native_Qt3DRender_QRenderState_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(state));
    }
    
    @io.qt.QtUninvokable
    private native void removeRenderState_native_Qt3DRender_QRenderState_ptr(long __this__nativeId, long state);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#renderStates">Qt3DRender::QRenderPass::renderStates()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QRenderState> renderStates(){
        return renderStates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QRenderState> renderStates_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#shaderProgram-prop">Qt3DRender::QRenderPass::setShaderProgram(Qt3DRender::QShaderProgram*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="shaderProgram")
    public final void setShaderProgram(io.qt.qt3d.render.QShaderProgram shaderProgram){
        setShaderProgram_native_Qt3DRender_QShaderProgram_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(shaderProgram));
    }
    
    private native void setShaderProgram_native_Qt3DRender_QShaderProgram_ptr(long __this__nativeId, long shaderProgram);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#shaderProgram-prop">Qt3DRender::QRenderPass::shaderProgram()const</a></p>
     */
    @io.qt.QtPropertyReader(name="shaderProgram")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QShaderProgram shaderProgram(){
        return shaderProgram_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QShaderProgram shaderProgram_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderPass(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderPass(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderPass instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QRenderPass.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates a Render Pass</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html">Qt3DRender::QRenderPass</a></p>
 */
public class QRenderPass extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderPass.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#shaderProgram-prop">Qt3DRender::QRenderPass::shaderProgramChanged(Qt3DRender::QShaderProgram*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="shaderProgram")
    public final Signal1<io.qt.qt3d.render.QShaderProgram> shaderProgramChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRenderPass(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderPass() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#QRenderPass">Qt3DRender::QRenderPass::QRenderPass(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderPass(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderPass instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#addFilterKey">Qt3DRender::QRenderPass::addFilterKey(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addFilterKey(io.qt.qt3d.render.QFilterKey filterKey){
        addFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void addFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#addParameter">Qt3DRender::QRenderPass::addParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addParameter(io.qt.qt3d.render.QParameter p){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#addRenderState">Qt3DRender::QRenderPass::addRenderState(Qt3DRender::QRenderState*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addRenderState(io.qt.qt3d.render.QRenderState state){
        addRenderState_native_Qt3DRender_QRenderState_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(state));
    }
    
    @io.qt.QtUninvokable
    private native void addRenderState_native_Qt3DRender_QRenderState_ptr(long __this__nativeId, long state);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#filterKeys">Qt3DRender::QRenderPass::filterKeys()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QFilterKey> filterKeys(){
        return filterKeys_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QFilterKey> filterKeys_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#parameters">Qt3DRender::QRenderPass::parameters()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#removeFilterKey">Qt3DRender::QRenderPass::removeFilterKey(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeFilterKey(io.qt.qt3d.render.QFilterKey filterKey){
        removeFilterKey_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void removeFilterKey_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#removeParameter">Qt3DRender::QRenderPass::removeParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.QParameter p){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#removeRenderState">Qt3DRender::QRenderPass::removeRenderState(Qt3DRender::QRenderState*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeRenderState(io.qt.qt3d.render.QRenderState state){
        removeRenderState_native_Qt3DRender_QRenderState_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(state));
    }
    
    @io.qt.QtUninvokable
    private native void removeRenderState_native_Qt3DRender_QRenderState_ptr(long __this__nativeId, long state);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#renderStates">Qt3DRender::QRenderPass::renderStates()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QRenderState> renderStates(){
        return renderStates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QRenderState> renderStates_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#shaderProgram-prop">Qt3DRender::QRenderPass::setShaderProgram(Qt3DRender::QShaderProgram*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="shaderProgram")
    public final void setShaderProgram(io.qt.qt3d.render.QShaderProgram shaderProgram){
        setShaderProgram_native_Qt3DRender_QShaderProgram_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(shaderProgram));
    }
    
    private native void setShaderProgram_native_Qt3DRender_QShaderProgram_ptr(long __this__nativeId, long shaderProgram);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderpass.html#shaderProgram-prop">Qt3DRender::QRenderPass::shaderProgram()const</a></p>
     */
    @io.qt.QtPropertyReader(name="shaderProgram")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QShaderProgram shaderProgram(){
        return shaderProgram_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QShaderProgram shaderProgram_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderPass(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderPass(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderPass instance, QDeclarativeConstructor constructor);
    
}
